/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.process.web.ui.internal.admin.projects.ManageProjectAreas");

dojo.require("dojox.data.dom");

dojo.require("net.jazz.ajax.ui.PlatformUI");

dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");

dojo.require("com.ibm.team.process.web.client.projectarea");
dojo.require("com.ibm.team.repository.web.ui.internal.admin.ItemList");
dojo.require("com.ibm.team.process.web.client.internal.ProcessClient");

var ProcessClient = com.ibm.team.process.web.client.internal.ProcessClient;
var ServiceResponseHandler = com.ibm.team.repository.web.transport.ServiceResponseHandler;

function setText(e, text){
	e.appendChild(document.createTextNode(text));
}

var PROJECT_ACTION_PREFIX = "com.ibm.team.process.editProjectArea&itemId=";

dojo.declare("com.ibm.team.process.web.ui.internal.admin.projects.ManageProjectAreas", com.ibm.team.repository.web.ui.internal.admin.ItemList, {
	
	postCreate: function() {
		setText(this.heading, "Active Project Areas");
		setText(this.description, "Use this interface to create and update project areas.  To create a new project area, click the \"Create Project Area\" button below.  To edit an existing project area, click the appropriate row in the table below.");
		this.tableHeading.parentNode.removeChild(this.tableHeading);
		this.setHeaderRow(["Name", "Description"]);
		this.headerRow.cells[0].style.width = "30%";
		this.addNewButton(PROJECT_ACTION_PREFIX + "new", "Create Project Area");
		this.refresh();
	},
	
	refresh: function () {
		this.clearState();
		var tr = document.createElement("tr");
		var td = document.createElement("td");
		td.colSpan = 2;
		td.appendChild(document.createTextNode("Loading..."));
		tr.appendChild(td);
		this.tbody.appendChild(tr);
		var srh = new ServiceResponseHandler(this, "showProjects", "handleError");
		ProcessClient.getAllProjectAreas(srh, { hideArchivedProjects: true });
	},
	
	clearState: function () {
		dojox.data.dom.removeChildren(this.tbody);
		dojox.data.dom.removeChildren(this.messageDiv);
		dojox.data.dom.removeChildren(this.messageBox);
		this.messageBox.className = "";
	},
	
	showProjects: function(data) {
		dojox.data.dom.removeChildren(this.tbody);
		if (data != null) {
			var sortedData = data.sort(function (a,b) {
				return a.name > b.name ? 1 : a.name < b.name ? -1 : 0;
			});
			for (var i=0; i < sortedData.length; i++) {
				var actionHref = PROJECT_ACTION_PREFIX + sortedData[i].itemId;
				var descNode = document.createElement("div");
				descNode.appendChild(document.createTextNode(sortedData[i].summary));
				if (sortedData[i].description) {
					descNode.appendChild(document.createElement("br"));
					descNode.appendChild(document.createElement("br"));
					descNode.appendChild(document.createTextNode(sortedData[i].description));
				}
				var row = this.addRow(actionHref, [sortedData[i].name, descNode]);
				
				var archiveIcon = document.createElement("img");
				archiveIcon.src = dojo.moduleUrl("com.ibm.team.repository.web", "ui/internal/images/archive.gif");
				archiveIcon.title = "Archive Project Area";
				archiveIcon.className = "archiveIcon";
				archiveIcon.projectItemId = sortedData[i].itemId;
				this.connect(archiveIcon,"onmouseover", function (e) {
					e.target.src = dojo.moduleUrl("com.ibm.team.repository.web", "ui/internal/images/archive_hov.gif");
				});
				this.connect(archiveIcon, "onmouseout", function (e) {
					e.target.src = dojo.moduleUrl("com.ibm.team.repository.web", "ui/internal/images/archive.gif");
				});
				this.connect(archiveIcon, "onclick", function (e) {
					dojo.stopEvent(e);
					if (confirm("Are you sure you want to archive this project area and all child team areas?\n\nThis action cannot be undone.")) {
						this.archiveProject(e.target.projectItemId);
					}
				});
				row.cells[0].insertBefore(archiveIcon, row.cells[0].firstChild);
				dojo.toggleClass(row.parentNode,"projectTable",true);
			}
		}
		else {
			this.messageDiv.appendChild(document.createTextNode("No project areas exist"));
		}
	},
	
	archiveProject: function (itemId) {
		var srh = new ServiceResponseHandler(this, "archiveCallback", "archiveErrorCallback");
		this.displayPendingMessage("Project area archive in progress");
		ProcessClient.postArchiveProjectArea({ uuid: itemId }, srh);
	},
	
	archiveCallback: function () {
		this.refresh();
		this.displaySuccessMessage("Project area archived successfully");
	},
	
	archiveErrorCallback: function (err) {
		this.displayErrorMessage("Error archiving project area: " + err.message);
	}
});

})();